@@ -1,6 +1,6 @@
 /* InspIRCd 3.0 functions
  *
- * (C) 2003-2023 Anope Team
+ * (C) 2003-2024 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -112,6 +112,11 @@ class InspIRCd3Proto : public IRCDProto
 		user->KillInternal(source, buf);
 	}
 
+	void SendForceNickChange(User *u, const Anope::string &newnick, time_t when) anope_override
+	{
+		UplinkSocket::Message() << "SVSNICK " << u->GetUID() << " " << newnick << " " << when << " " << u->timestamp;
+	}
+
 	void SendGlobalNotice(BotInfo *bi, const Server *dest, const Anope::string &msg) anope_override
 	{
 		UplinkSocket::Message(bi) << "NOTICE $" << dest->GetName() << " :" << msg;
